CHIPSET(0x1602, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x1606, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x160A, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x160B, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x160D, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x160E, bdw_gt1, "BDW GT1", "Intel(R) HD Graphics")
CHIPSET(0x1612, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics 5600")
CHIPSET(0x1616, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics 5500")
CHIPSET(0x161A, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics P5700")
CHIPSET(0x161B, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics")
CHIPSET(0x161D, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics")
CHIPSET(0x161E, bdw_gt2, "BDW GT2", "Intel(R) HD Graphics 5300")
CHIPSET(0x1622, bdw_gt3, "BDW GT3", "Intel(R) Iris(R) Pro Graphics 6200")
CHIPSET(0x1626, bdw_gt3, "BDW GT3", "Intel(R) HD Graphics 6000")
CHIPSET(0x162A, bdw_gt3, "BDW GT3", "Intel(R) Iris(R) Pro Graphics P6300")
CHIPSET(0x162B, bdw_gt3, "BDW GT3", "Intel(R) Iris(R) Graphics 6100")
CHIPSET(0x162D, bdw_gt3, "BDW GT3", "Intel(R) HD Graphics")
CHIPSET(0x162E, bdw_gt3, "BDW GT3", "Intel(R) HD Graphics")

CHIPSET(0x1902, skl_gt1, "SKL GT1",  "Intel(R) HD Graphics 510")
CHIPSET(0x1906, skl_gt1, "SKL GT1",  "Intel(R) HD Graphics 510")
CHIPSET(0x190A, skl_gt1, "SKL GT1",  "Intel(R) HD Graphics")
CHIPSET(0x190B, skl_gt1, "SKL GT1",  "Intel(R) HD Graphics 510")
CHIPSET(0x190E, skl_gt1, "SKL GT1",  "Intel(R) HD Graphics")
CHIPSET(0x1912, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics 530")
CHIPSET(0x1913, skl_gt2, "SKL GT2F", "Intel(R) HD Graphics")
CHIPSET(0x1915, skl_gt2, "SKL GT2F", "Intel(R) HD Graphics")
CHIPSET(0x1916, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics 520")
CHIPSET(0x1917, skl_gt2, "SKL GT2F", "Intel(R) HD Graphics")
CHIPSET(0x191A, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics")
CHIPSET(0x191B, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics 530")
CHIPSET(0x191D, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics P530")
CHIPSET(0x191E, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics 515")
CHIPSET(0x1921, skl_gt2, "SKL GT2",  "Intel(R) HD Graphics 520")
CHIPSET(0x1923, skl_gt3, "SKL GT3",  "Intel(R) HD Graphics 535")
CHIPSET(0x1926, skl_gt3, "SKL GT3",  "Intel(R) Iris(R) Graphics 540")
CHIPSET(0x1927, skl_gt3, "SKL GT3",  "Intel(R) Iris(R) Graphics 550")
CHIPSET(0x192A, skl_gt4, "SKL GT4",  "Intel(R) HD Graphics")
CHIPSET(0x192B, skl_gt3, "SKL GT3",  "Intel(R) Iris(R) Graphics 555")
CHIPSET(0x192D, skl_gt3, "SKL GT3",  "Intel(R) Iris(R) Graphics P555")
CHIPSET(0x1932, skl_gt4, "SKL GT4",  "Intel(R) Iris(R) Pro Graphics 580")
CHIPSET(0x193A, skl_gt4, "SKL GT4",  "Intel(R) Iris(R) Pro Graphics P580")
CHIPSET(0x193B, skl_gt4, "SKL GT4",  "Intel(R) Iris(R) Pro Graphics 580")
CHIPSET(0x193D, skl_gt4, "SKL GT4",  "Intel(R) Iris(R) Pro Graphics P580")

CHIPSET(0x0A84, bxt,     "BXT 3",    "Intel(R) HD Graphics")
CHIPSET(0x1A84, bxt,     "BXT 3",    "Intel(R) HD Graphics")
CHIPSET(0x1A85, bxt_2x6, "BXT 2",    "Intel(R) HD Graphics")
CHIPSET(0x5A84, bxt,     "APL 3",    "Intel(R) HD Graphics 505")
CHIPSET(0x5A85, bxt_2x6, "APL 2",    "Intel(R) HD Graphics 500")

CHIPSET(0x3184, glk,     "GLK 3",    "Intel(R) UHD Graphics 605")
CHIPSET(0x3185, glk_2x6, "GLK 2",    "Intel(R) UHD Graphics 600")

CHIPSET(0x5902, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics 610")
CHIPSET(0x5906, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics 610")
CHIPSET(0x590A, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics")
CHIPSET(0x5908, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics")
CHIPSET(0x590B, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics 610")
CHIPSET(0x590E, kbl_gt1,   "KBL GT1",   "Intel(R) HD Graphics")
CHIPSET(0x5913, kbl_gt1_5, "KBL GT1.5", "Intel(R) HD Graphics")
CHIPSET(0x5915, kbl_gt1_5, "KBL GT1.5", "Intel(R) HD Graphics")
CHIPSET(0x5917, kbl_gt2,   "KBL GT2",   "Intel(R) UHD Graphics 620")
CHIPSET(0x5912, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics 630")
CHIPSET(0x5916, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics 620")
CHIPSET(0x591A, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics P630")
CHIPSET(0x591B, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics 630")
CHIPSET(0x591D, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics P630")
CHIPSET(0x591E, kbl_gt2,   "KBL GT2",   "Intel(R) HD Graphics 615")
CHIPSET(0x5921, kbl_gt2,   "KBL GT2F",  "Intel(R) HD Graphics 620")
CHIPSET(0x5923, kbl_gt3,   "KBL GT3",   "Intel(R) HD Graphics 635")
CHIPSET(0x5926, kbl_gt3,   "KBL GT3",   "Intel(R) Iris(R) Plus Graphics 640 (Kaby Lake GT3e)")
CHIPSET(0x5927, kbl_gt3,   "KBL GT3",   "Intel(R) Iris(R) Plus Graphics 650 (Kaby Lake GT3e)")
CHIPSET(0x593B, kbl_gt4,   "KBL GT4",   "Intel(R) HD Graphics")

CHIPSET(0x591C, kbl_gt2, "AML-KBL", "Intel(R) UHD Graphics 615")
CHIPSET(0x87C0, kbl_gt2, "AML-KBL", "Intel(R) UHD Graphics 617")

CHIPSET(0x87CA, cfl_gt2, "AML-CFL", "Intel(R) UHD Graphics")

CHIPSET(0x3E90, cfl_gt1, "CFL GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x3E93, cfl_gt1, "CFL GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x3E99, cfl_gt1, "CFL GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x3E9C, cfl_gt1, "CFL GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x3E91, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x3E92, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x3E96, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics P630")
CHIPSET(0x3E98, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x3E9A, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics P630")
CHIPSET(0x3E9B, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x3E94, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics P630")
CHIPSET(0x3EA9, cfl_gt2, "CFL GT2", "Intel(R) UHD Graphics 620")
CHIPSET(0x3EA5, cfl_gt3, "CFL GT3", "Intel(R) Iris(R) Plus Graphics 655")
CHIPSET(0x3EA6, cfl_gt3, "CFL GT3", "Intel(R) Iris(R) Plus Graphics 645")
CHIPSET(0x3EA7, cfl_gt3, "CFL GT3", "Intel(R) HD Graphics")
CHIPSET(0x3EA8, cfl_gt3, "CFL GT3", "Intel(R) Iris(R) Plus Graphics 655")

CHIPSET(0x3EA1, cfl_gt1, "WHL GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x3EA4, cfl_gt1, "WHL GT1", "Intel(R) UHD Graphics")
CHIPSET(0x3EA0, cfl_gt2, "WHL GT2", "Intel(R) UHD Graphics 620")
CHIPSET(0x3EA3, cfl_gt2, "WHL GT2", "Intel(R) UHD Graphics")
CHIPSET(0x3EA2, cfl_gt3, "WHL GT3", "Intel(R) UHD Graphics")

CHIPSET(0x9B21, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BA0, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BA2, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BA4, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BA5, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x9BA8, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics 610")
CHIPSET(0x9BAA, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BAB, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9BAC, cfl_gt1, "CML GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9B41, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BC0, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BC2, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BC4, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BC5, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x9BC6, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics P630")
CHIPSET(0x9BC8, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics 630")
CHIPSET(0x9BCA, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BCB, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BCC, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9BE6, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics P630")
CHIPSET(0x9BF6, cfl_gt2, "CML GT2", "Intel(R) UHD Graphics P630")

CHIPSET(0x8A50, icl_gt2,   "ICL GT2",   "Intel(R) HD Graphics")
CHIPSET(0x8A51, icl_gt2,   "ICL GT2",   "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A52, icl_gt2,   "ICL GT2",   "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A53, icl_gt2,   "ICL GT2",   "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A54, icl_gt1_5, "ICL GT1.5", "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A56, icl_gt1,   "ICL GT1",   "Intel(R) UHD Graphics")
CHIPSET(0x8A57, icl_gt1_5, "ICL GT1.5", "Intel(R) HD Graphics")
CHIPSET(0x8A58, icl_gt1,   "ICL GT1",   "Intel(R) UHD Graphics")
CHIPSET(0x8A59, icl_gt1_5, "ICL GT1.5", "Intel(R) HD Graphics")
CHIPSET(0x8A5A, icl_gt1_5, "ICL GT1.5", "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A5B, icl_gt1,   "ICL GT1",   "Intel(R) HD Graphics")
CHIPSET(0x8A5C, icl_gt1_5, "ICL GT1.5", "Intel(R) Iris(R) Plus Graphics")
CHIPSET(0x8A5D, icl_gt1,   "ICL GT1",   "Intel(R) HD Graphics")
CHIPSET(0x8A71, icl_gt0_5, "ICL GT0.5", "Intel(R) HD Graphics")

CHIPSET(0x4500, ehl_4x8, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4541, ehl_2x4, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4551, ehl_4x4, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4555, ehl_2x8, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4557, ehl_4x5, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4571, ehl_4x8, "EHL", "Intel(R) UHD Graphics")
CHIPSET(0x4E51, ehl_4x4, "JSL", "Intel(R) UHD Graphics")
CHIPSET(0x4E55, ehl_2x8, "JSL", "Intel(R) UHD Graphics")
CHIPSET(0x4E57, ehl_4x5, "JSL", "Intel(R) UHD Graphics")
CHIPSET(0x4E61, ehl_4x6, "JSL", "Intel(R) UHD Graphics")
CHIPSET(0x4E71, ehl_4x8, "JSL", "Intel(R) UHD Graphics")

CHIPSET(0x4c8a, rkl_gt1, "RKL GT1", "Intel(R) Graphics")
CHIPSET(0x4c8b, rkl_gt1, "RKL GT1", "Intel(R) Graphics")
CHIPSET(0x4c8c, rkl_gt05, "RKL GT0.5", "Intel(R) Graphics")
CHIPSET(0x4c90, rkl_gt1, "RKL GT1", "Intel(R) Graphics")
CHIPSET(0x4c9a, rkl_gt1, "RKL GT1", "Intel(R) Graphics")

CHIPSET(0x4680, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x4682, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x4688, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x468a, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x4690, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x4692, adl_gt1, "ADL-S GT1", "Intel(R) Graphics")
CHIPSET(0x4693, adl_gt05, "ADL-S GT0.5", "Intel(R) Graphics")

CHIPSET(0x4626, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x4628, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x462a, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a0, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a1, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a2, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a3, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a6, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46a8, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46aa, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46b0, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46b1, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46b2, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46b3, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46c0, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46c1, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46c2, adl_gt2, "ADL GT2", "Intel(R) Graphics")
CHIPSET(0x46c3, adl_gt2, "ADL GT2", "Intel(R) Graphics")

CHIPSET(0x46d0, adl_n, "ADL-N", "Intel(R) Graphics")
CHIPSET(0x46d1, adl_n, "ADL-N", "Intel(R) Graphics")
CHIPSET(0x46d2, adl_n, "ADL-N", "Intel(R) Graphics")

CHIPSET(0x9A40, tgl_gt2, "TGL GT2", "Intel(R) Xe Graphics")
CHIPSET(0x9A49, tgl_gt2, "TGL GT2", "Intel(R) Xe Graphics")
CHIPSET(0x9A59, tgl_gt2, "TGL GT2", "Intel(R) Graphics")
CHIPSET(0x9A60, tgl_gt1, "TGL GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9A68, tgl_gt1, "TGL GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9A70, tgl_gt1, "TGL GT1", "Intel(R) UHD Graphics")
CHIPSET(0x9A78, tgl_gt2, "TGL GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9AC0, tgl_gt2, "TGL GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9AC9, tgl_gt2, "TGL GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9AD9, tgl_gt2, "TGL GT2", "Intel(R) UHD Graphics")
CHIPSET(0x9AF8, tgl_gt2, "TGL GT2", "Intel(R) UHD Graphics")

CHIPSET(0xa780, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa781, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa782, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa783, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa788, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa789, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa78a, rpl, "RPL-S", "Intel(R) Graphics")
CHIPSET(0xa78b, rpl, "RPL-S", "Intel(R) Graphics")

CHIPSET(0xa720, rpl_p, "RPL-P", "Intel(R) Graphics")
CHIPSET(0xa721, rpl_p, "RPL-P", "Intel(R) Graphics")
CHIPSET(0xa7a0, rpl_p, "RPL-P", "Intel(R) Graphics")
CHIPSET(0xa7a1, rpl_p, "RPL-P", "Intel(R) Graphics")
CHIPSET(0xa7a8, rpl_p, "RPL-P", "Intel(R) Graphics")
CHIPSET(0xa7a9, rpl_p, "RPL-P", "Intel(R) Graphics")

CHIPSET(0x4905, dg1, "DG1", "Intel(R) Graphics")
CHIPSET(0x4906, dg1, "DG1", "Intel(R) Graphics")
CHIPSET(0x4907, sg1, "SG1", "Intel(R) Graphics")
CHIPSET(0x4908, dg1, "DG1", "Intel(R) Graphics")
CHIPSET(0x4909, dg1, "DG1", "Intel(R) Graphics")

/* Commented devices are waiting on i915 upstream support */
/* CHIPSET(0x4f80, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f81, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f82, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f83, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f84, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f87, dg2_g11, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x4f88, dg2_g11, "DG2", "Intel(R) Graphics") */
CHIPSET(0x5690, dg2_g10, "DG2", "Intel(R) Graphics")
CHIPSET(0x5691, dg2_g10, "DG2", "Intel(R) Graphics")
CHIPSET(0x5692, dg2_g10, "DG2", "Intel(R) Graphics")
CHIPSET(0x5693, dg2_g11, "DG2", "Intel(R) Graphics")
CHIPSET(0x5694, dg2_g11, "DG2", "Intel(R) Graphics")
CHIPSET(0x5695, dg2_g11, "DG2", "Intel(R) Graphics")
CHIPSET(0x5696, dg2_g12, "DG2", "Intel(R) Graphics")
CHIPSET(0x5697, dg2_g12, "DG2", "Intel(R) Graphics")
/* CHIPSET(0x56a0, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a1, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a2, dg2_g10, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a3, dg2_g12, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a4, dg2_g12, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a5, dg2_g11, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56a6, dg2_g11, "DG2", "Intel(R) Graphics") */
CHIPSET(0x56b0, dg2_g11, "DG2", "Intel(R) Graphics")
/* CHIPSET(0x56b1, dg2_g11, "DG2", "Intel(R) Graphics") */
CHIPSET(0x56b2, dg2_g12, "DG2", "Intel(R) Graphics")
/* CHIPSET(0x56b3, dg2_g12, "DG2", "Intel(R) Graphics") */
/* CHIPSET(0x56c0, dg2_g10, "ATS-M", "Intel(R) Graphics") */
/* CHIPSET(0x56c1, dg2_g11, "ATS-M", "Intel(R) Graphics") */
